"""The calibration commands module.

These commands are used in the following models:
AWG5200, AWG70KA, AWG70KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CALibration:ABORt
    - CALibration:ALL
    - CALibration:ALL?
    - CALibration:CATalog? [{ALL|<subsystem>}[,{ALL|<area>}]]
    - CALibration:LOG:CLEar
    - CALibration:LOG:FAILuresonly {OFF|ON|0|1}
    - CALibration:LOG:FAILuresonly?
    - CALibration:LOG?
    - CALibration:RESTore
    - CALibration:RESult:TEMPerature?
    - CALibration:RESult:TIME?
    - CALibration:RESult?
    - CALibration:RUNNing?
    - CALibration:STARt
    - CALibration:STATe:FACTory? [<subsystem>][,<area>]]
    - CALibration:STATe:USER? [<subsystem>[,<area>]]
    - CALibration:STOP:STATe?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdReadWithArguments, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class CalibrationStopState(SCPICmdRead):
    """The ``CALibration:STOP:STATe`` command.

    **Description:**
        - This command returns the state of the calibration procedure.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:STOP:STATe?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:STOP:STATe?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibration:STOP:STATe?
    """


class CalibrationStop(SCPICmdRead):
    """The ``CALibration:STOP`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:STOP?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:STOP?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.state``: The ``CALibration:STOP:STATe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._state = CalibrationStopState(device, f"{self._cmd_syntax}:STATe")

    @property
    def state(self) -> CalibrationStopState:
        """Return the ``CALibration:STOP:STATe`` command.

        **Description:**
            - This command returns the state of the calibration procedure.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:STOP:STATe?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:STOP:STATe?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibration:STOP:STATe?
        """
        return self._state


class CalibrationStateUser(SCPICmdReadWithArguments):
    """The ``CALibration:STATe:USER`` command.

    **Description:**
        - This command returns the current user state of the calibration for the AWG. A calibration
          state will be Calibrated or Uncalibrated. Areas will be calibrated when all procedures for
          that area have been executed and passed. Subsystems will be calibrated when all areas for
          that subsystem are calibrated. Each calibrated (as opposed to uncalibrated) state will
          have a temperature and date time. An uncalibrated state will not have a valid temperature
          or date time and should be ignored.

    **Usage:**
        - Using the ``.query(argument)`` method will send the ``CALibration:STATe:USER? argument``
          query.
        - Using the ``.verify(argument, value)`` method will send the
          ``CALibration:STATe:USER? argument`` query and raise an AssertionError if the returned
          value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibration:STATe:USER? [<subsystem>[,<area>]]
    """


class CalibrationStateFactory(SCPICmdReadWithArguments):
    """The ``CALibration:STATe:FACTory`` command.

    **Description:**
        - This command returns the current factory state of the calibration for the AWG. A
          calibration state will be Calibrated or Uncalibrated. Areas will be calibrated when all
          procedures for that area have been executed and passed. Subsystems will be calibrated when
          all areas for that subsystem are calibrated. Each calibrated (as opposed to uncalibrated)
          state will have a temperature and date time. An uncalibrated state will not have a valid
          temperature or date time and should be ignored.

    **Usage:**
        - Using the ``.query(argument)`` method will send the
          ``CALibration:STATe:FACTory? argument`` query.
        - Using the ``.verify(argument, value)`` method will send the
          ``CALibration:STATe:FACTory? argument`` query and raise an AssertionError if the returned
          value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibration:STATe:FACTory? [<subsystem>][,<area>]]
    """


class CalibrationState(SCPICmdRead):
    """The ``CALibration:STATe`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:STATe?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:STATe?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.factory``: The ``CALibration:STATe:FACTory`` command.
        - ``.user``: The ``CALibration:STATe:USER`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._factory = CalibrationStateFactory(device, f"{self._cmd_syntax}:FACTory")
        self._user = CalibrationStateUser(device, f"{self._cmd_syntax}:USER")

    @property
    def factory(self) -> CalibrationStateFactory:
        """Return the ``CALibration:STATe:FACTory`` command.

        **Description:**
            - This command returns the current factory state of the calibration for the AWG. A
              calibration state will be Calibrated or Uncalibrated. Areas will be calibrated when
              all procedures for that area have been executed and passed. Subsystems will be
              calibrated when all areas for that subsystem are calibrated. Each calibrated (as
              opposed to uncalibrated) state will have a temperature and date time. An uncalibrated
              state will not have a valid temperature or date time and should be ignored.

        **Usage:**
            - Using the ``.query(argument)`` method will send the
              ``CALibration:STATe:FACTory? argument`` query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CALibration:STATe:FACTory? argument`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibration:STATe:FACTory? [<subsystem>][,<area>]]
        """
        return self._factory

    @property
    def user(self) -> CalibrationStateUser:
        """Return the ``CALibration:STATe:USER`` command.

        **Description:**
            - This command returns the current user state of the calibration for the AWG. A
              calibration state will be Calibrated or Uncalibrated. Areas will be calibrated when
              all procedures for that area have been executed and passed. Subsystems will be
              calibrated when all areas for that subsystem are calibrated. Each calibrated (as
              opposed to uncalibrated) state will have a temperature and date time. An uncalibrated
              state will not have a valid temperature or date time and should be ignored.

        **Usage:**
            - Using the ``.query(argument)`` method will send the
              ``CALibration:STATe:USER? argument`` query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CALibration:STATe:USER? argument`` query and raise an AssertionError if the returned
              value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibration:STATe:USER? [<subsystem>[,<area>]]
        """
        return self._user


class CalibrationStart(SCPICmdWriteNoArguments):
    """The ``CALibration:STARt`` command.

    **Description:**
        - This command starts the calibration.

    **Usage:**
        - Using the ``.write()`` method will send the ``CALibration:STARt`` command.

    **SCPI Syntax:**

    ::

        - CALibration:STARt
    """


class CalibrationRunning(SCPICmdRead):
    """The ``CALibration:RUNNing`` command.

    **Description:**
        - This command returns the name of the subsystem, area, and procedure in progress. This
          command can be issued while procedure is in progress.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:RUNNing?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:RUNNing?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibration:RUNNing?
    """


class CalibrationResultTime(SCPICmdRead):
    """The ``CALibration:RESult:TIME`` command.

    **Description:**
        - This command returns the time of the last calibration.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:RESult:TIME?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:RESult:TIME?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibration:RESult:TIME?
    """


class CalibrationResultTemperature(SCPICmdRead):
    """The ``CALibration:RESult:TEMPerature`` command.

    **Description:**
        - This command returns the temperature of the last calibration. All temperatures are in °C.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:RESult:TEMPerature?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:RESult:TEMPerature?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibration:RESult:TEMPerature?
    """


class CalibrationResult(SCPICmdRead):
    """The ``CALibration:RESult`` command.

    **Description:**
        - This command returns the status of the last calibration procedure. This query-only command
          can be issued while calibration is in progress.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:RESult?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:RESult?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibration:RESult?

    Properties:
        - ``.temperature``: The ``CALibration:RESult:TEMPerature`` command.
        - ``.time``: The ``CALibration:RESult:TIME`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._temperature = CalibrationResultTemperature(device, f"{self._cmd_syntax}:TEMPerature")
        self._time = CalibrationResultTime(device, f"{self._cmd_syntax}:TIME")

    @property
    def temperature(self) -> CalibrationResultTemperature:
        """Return the ``CALibration:RESult:TEMPerature`` command.

        **Description:**
            - This command returns the temperature of the last calibration. All temperatures are in
              °C.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:RESult:TEMPerature?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:RESult:TEMPerature?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibration:RESult:TEMPerature?
        """
        return self._temperature

    @property
    def time(self) -> CalibrationResultTime:
        """Return the ``CALibration:RESult:TIME`` command.

        **Description:**
            - This command returns the time of the last calibration.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:RESult:TIME?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:RESult:TIME?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibration:RESult:TIME?
        """
        return self._time


class CalibrationRestore(SCPICmdWriteNoArguments):
    """The ``CALibration:RESTore`` command.

    **Description:**
        - This command restores the calibration constants from the factory non-volatile memory and
          copied to user storage.

    **Usage:**
        - Using the ``.write()`` method will send the ``CALibration:RESTore`` command.

    **SCPI Syntax:**

    ::

        - CALibration:RESTore
    """


class CalibrationLogFailuresonly(SCPICmdWrite, SCPICmdRead):
    """The ``CALibration:LOG:FAILuresonly`` command.

    **Description:**
        - This command sets or returns the flag that controls the amount of result information saved
          into the log. This controls all tests that pass or fail or only tests that fail. It is
          important to note, that details are generated during the test, and need to be saved during
          the test execution.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:LOG:FAILuresonly?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:LOG:FAILuresonly?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CALibration:LOG:FAILuresonly value``
          command.

    **SCPI Syntax:**

    ::

        - CALibration:LOG:FAILuresonly {OFF|ON|0|1}
        - CALibration:LOG:FAILuresonly?

    **Info:**
        - ``*RST`` sets this to 0.
    """


class CalibrationLogClear(SCPICmdWriteNoArguments):
    """The ``CALibration:LOG:CLEar`` command.

    **Description:**
        - This command clears the results log. The command works when in the active mode for
          calibration. See the ``ACTIVE:MODE`` command.

    **Usage:**
        - Using the ``.write()`` method will send the ``CALibration:LOG:CLEar`` command.

    **SCPI Syntax:**

    ::

        - CALibration:LOG:CLEar
    """


class CalibrationLog(SCPICmdRead):
    """The ``CALibration:LOG`` command.

    **Description:**
        - This command returns a string of continuous concatenated calibration results. The start
          time is recorded plus one or more <cal ``path>:<cal`` name> <result>. This command can be
          issued while calibration is still in progress. Use the ``CALIBRATION:LOG:CLEAR`` command
          to start a fresh log and provide additional information. Log results are still valid if
          the calibration is aborted and the calibration constants are restored.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:LOG?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:LOG?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibration:LOG?

    Properties:
        - ``.clear``: The ``CALibration:LOG:CLEar`` command.
        - ``.failuresonly``: The ``CALibration:LOG:FAILuresonly`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._clear = CalibrationLogClear(device, f"{self._cmd_syntax}:CLEar")
        self._failuresonly = CalibrationLogFailuresonly(device, f"{self._cmd_syntax}:FAILuresonly")

    @property
    def clear(self) -> CalibrationLogClear:
        """Return the ``CALibration:LOG:CLEar`` command.

        **Description:**
            - This command clears the results log. The command works when in the active mode for
              calibration. See the ``ACTIVE:MODE`` command.

        **Usage:**
            - Using the ``.write()`` method will send the ``CALibration:LOG:CLEar`` command.

        **SCPI Syntax:**

        ::

            - CALibration:LOG:CLEar
        """
        return self._clear

    @property
    def failuresonly(self) -> CalibrationLogFailuresonly:
        """Return the ``CALibration:LOG:FAILuresonly`` command.

        **Description:**
            - This command sets or returns the flag that controls the amount of result information
              saved into the log. This controls all tests that pass or fail or only tests that fail.
              It is important to note, that details are generated during the test, and need to be
              saved during the test execution.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:LOG:FAILuresonly?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:LOG:FAILuresonly?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``CALibration:LOG:FAILuresonly value`` command.

        **SCPI Syntax:**

        ::

            - CALibration:LOG:FAILuresonly {OFF|ON|0|1}
            - CALibration:LOG:FAILuresonly?

        **Info:**
            - ``*RST`` sets this to 0.
        """
        return self._failuresonly


class CalibrationCatalog(SCPICmdReadWithArguments):
    """The ``CALibration:CATalog`` command.

    **Description:**
        - This command returns the list of calibration procedures. All tests are grouped by areas.
          All areas are grouped by subsystems. The available subsystems, areas, and tests depend on
          the type of testing (such as POST or ALL).

    **Usage:**
        - Using the ``.query(argument)`` method will send the ``CALibration:CATalog? argument``
          query.
        - Using the ``.verify(argument, value)`` method will send the
          ``CALibration:CATalog? argument`` query and raise an AssertionError if the returned value
          does not match ``value``.

    **SCPI Syntax:**

    ::

        - CALibration:CATalog? [{ALL|<subsystem>}[,{ALL|<area>}]]
    """


class CalibrationAll(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``CALibration:ALL`` command.

    **Description:**
        - The CALibration[``:ALL``] command performs an internal calibration. The
          CALibration[``:ALL``]? command performs an internal calibration and returns 0 (Pass) or a
          calibration error code.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration:ALL?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration:ALL?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write()`` method will send the ``CALibration:ALL`` command.

    **SCPI Syntax:**

    ::

        - CALibration:ALL
        - CALibration:ALL?
    """


class CalibrationAbort(SCPICmdWriteNoArguments):
    """The ``CALibration:ABORt`` command.

    **Description:**
        - This command stops the self calibration process and restores the previous calibration
          constants.

    **Usage:**
        - Using the ``.write()`` method will send the ``CALibration:ABORt`` command.

    **SCPI Syntax:**

    ::

        - CALibration:ABORt
    """


#  pylint: disable=too-many-instance-attributes
class Calibration(SCPICmdRead):
    """The ``CALibration`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CALibration?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibration?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.abort``: The ``CALibration:ABORt`` command.
        - ``.catalog``: The ``CALibration:CATalog`` command.
        - ``.log``: The ``CALibration:LOG`` command.
        - ``.restore``: The ``CALibration:RESTore`` command.
        - ``.result``: The ``CALibration:RESult`` command.
        - ``.running``: The ``CALibration:RUNNing`` command.
        - ``.start``: The ``CALibration:STARt`` command.
        - ``.state``: The ``CALibration:STATe`` command tree.
        - ``.stop``: The ``CALibration:STOP`` command tree.
        - ``.all``: The ``CALibration:ALL`` command.
    """

    def __init__(
        self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CALibration"
    ) -> None:
        super().__init__(device, cmd_syntax)
        self._abort = CalibrationAbort(device, f"{self._cmd_syntax}:ABORt")
        self._catalog = CalibrationCatalog(device, f"{self._cmd_syntax}:CATalog")
        self._log = CalibrationLog(device, f"{self._cmd_syntax}:LOG")
        self._restore = CalibrationRestore(device, f"{self._cmd_syntax}:RESTore")
        self._result = CalibrationResult(device, f"{self._cmd_syntax}:RESult")
        self._running = CalibrationRunning(device, f"{self._cmd_syntax}:RUNNing")
        self._start = CalibrationStart(device, f"{self._cmd_syntax}:STARt")
        self._state = CalibrationState(device, f"{self._cmd_syntax}:STATe")
        self._stop = CalibrationStop(device, f"{self._cmd_syntax}:STOP")
        self._all = CalibrationAll(device, f"{self._cmd_syntax}:ALL")

    @property
    def abort(self) -> CalibrationAbort:
        """Return the ``CALibration:ABORt`` command.

        **Description:**
            - This command stops the self calibration process and restores the previous calibration
              constants.

        **Usage:**
            - Using the ``.write()`` method will send the ``CALibration:ABORt`` command.

        **SCPI Syntax:**

        ::

            - CALibration:ABORt
        """
        return self._abort

    @property
    def catalog(self) -> CalibrationCatalog:
        """Return the ``CALibration:CATalog`` command.

        **Description:**
            - This command returns the list of calibration procedures. All tests are grouped by
              areas. All areas are grouped by subsystems. The available subsystems, areas, and tests
              depend on the type of testing (such as POST or ALL).

        **Usage:**
            - Using the ``.query(argument)`` method will send the ``CALibration:CATalog? argument``
              query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CALibration:CATalog? argument`` query and raise an AssertionError if the returned
              value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibration:CATalog? [{ALL|<subsystem>}[,{ALL|<area>}]]
        """
        return self._catalog

    @property
    def log(self) -> CalibrationLog:
        """Return the ``CALibration:LOG`` command.

        **Description:**
            - This command returns a string of continuous concatenated calibration results. The
              start time is recorded plus one or more <cal ``path>:<cal`` name> <result>. This
              command can be issued while calibration is still in progress. Use the
              ``CALIBRATION:LOG:CLEAR`` command to start a fresh log and provide additional
              information. Log results are still valid if the calibration is aborted and the
              calibration constants are restored.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:LOG?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:LOG?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibration:LOG?

        Sub-properties:
            - ``.clear``: The ``CALibration:LOG:CLEar`` command.
            - ``.failuresonly``: The ``CALibration:LOG:FAILuresonly`` command.
        """
        return self._log

    @property
    def restore(self) -> CalibrationRestore:
        """Return the ``CALibration:RESTore`` command.

        **Description:**
            - This command restores the calibration constants from the factory non-volatile memory
              and copied to user storage.

        **Usage:**
            - Using the ``.write()`` method will send the ``CALibration:RESTore`` command.

        **SCPI Syntax:**

        ::

            - CALibration:RESTore
        """
        return self._restore

    @property
    def result(self) -> CalibrationResult:
        """Return the ``CALibration:RESult`` command.

        **Description:**
            - This command returns the status of the last calibration procedure. This query-only
              command can be issued while calibration is in progress.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:RESult?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:RESult?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibration:RESult?

        Sub-properties:
            - ``.temperature``: The ``CALibration:RESult:TEMPerature`` command.
            - ``.time``: The ``CALibration:RESult:TIME`` command.
        """
        return self._result

    @property
    def running(self) -> CalibrationRunning:
        """Return the ``CALibration:RUNNing`` command.

        **Description:**
            - This command returns the name of the subsystem, area, and procedure in progress. This
              command can be issued while procedure is in progress.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:RUNNing?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:RUNNing?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CALibration:RUNNing?
        """
        return self._running

    @property
    def start(self) -> CalibrationStart:
        """Return the ``CALibration:STARt`` command.

        **Description:**
            - This command starts the calibration.

        **Usage:**
            - Using the ``.write()`` method will send the ``CALibration:STARt`` command.

        **SCPI Syntax:**

        ::

            - CALibration:STARt
        """
        return self._start

    @property
    def state(self) -> CalibrationState:
        """Return the ``CALibration:STATe`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:STATe?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:STATe?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.factory``: The ``CALibration:STATe:FACTory`` command.
            - ``.user``: The ``CALibration:STATe:USER`` command.
        """
        return self._state

    @property
    def stop(self) -> CalibrationStop:
        """Return the ``CALibration:STOP`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:STOP?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:STOP?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.state``: The ``CALibration:STOP:STATe`` command.
        """
        return self._stop

    @property
    def all(self) -> CalibrationAll:
        """Return the ``CALibration:ALL`` command.

        **Description:**
            - The CALibration[``:ALL``] command performs an internal calibration. The
              CALibration[``:ALL``]? command performs an internal calibration and returns 0 (Pass)
              or a calibration error code.

        **Usage:**
            - Using the ``.query()`` method will send the ``CALibration:ALL?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibration:ALL?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write()`` method will send the ``CALibration:ALL`` command.

        **SCPI Syntax:**

        ::

            - CALibration:ALL
            - CALibration:ALL?
        """
        return self._all



# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The trigger commands module.

These commands are used in the following models:
SMU2601B, SMU2602B, SMU2604B, SMU2606B, SMU2611B, SMU2612B, SMU2614B, SMU2634B, SMU2635B, SMU2636B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:

::

    - trigger.blender[N].clear()
    - trigger.blender[N].orenable
    - trigger.blender[N].overrun
    - trigger.blender[N].reset()
    - trigger.blender[N].stimulus[M]
    - trigger.blender[N].wait()
    - trigger.clear()
    - trigger.generator[N].assert()
    - trigger.timer[N].clear()
    - trigger.timer[N].count
    - trigger.timer[N].delay
    - trigger.timer[N].delaylist
    - trigger.timer[N].overrun
    - trigger.timer[N].passthrough
    - trigger.timer[N].reset()
    - trigger.timer[N].stimulus
    - trigger.timer[N].wait()
    - trigger.wait()
"""
from typing import Dict, Optional, TYPE_CHECKING, Union

from .._helpers import (
    BaseTSPCmd,
    DefaultDictDeviceCommunication,
    DefaultDictPassKeyToFactory,
    NoDeviceProvidedError,
    ValidatedDynamicNumberCmd,
)

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


class TriggerTimerItem(ValidatedDynamicNumberCmd, BaseTSPCmd):
    """The ``trigger.timer[N]`` command tree.

    **Info:**
        - ``N``, the trigger timer number (1 to 8).

    Constants:
        - ``.EVENT_ID``: The trigger timer event number.

    Properties/methods:
        - ``.clear()``: The ``trigger.timer[N].clear()`` function.
        - ``.count``: The ``trigger.timer[N].count`` attribute.
        - ``.delay``: The ``trigger.timer[N].delay`` attribute.
        - ``.delaylist``: The ``trigger.timer[N].delaylist`` attribute.
        - ``.overrun``: The ``trigger.timer[N].overrun`` attribute.
        - ``.passthrough``: The ``trigger.timer[N].passthrough`` attribute.
        - ``.reset()``: The ``trigger.timer[N].reset()`` function.
        - ``.stimulus``: The ``trigger.timer[N].stimulus`` attribute.
        - ``.wait()``: The ``trigger.timer[N].wait()`` function.
    """

    EVENT_ID = "trigger.timer[N].EVENT_ID"
    """str: The trigger timer event number."""

    def __init__(self, device: Optional["TSPDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        # pylint: disable=invalid-name
        self.EVENT_ID = self.EVENT_ID.replace(
            "[N]", f"[{self._cmd_syntax.rsplit('[', maxsplit=1)[-1].split(']', maxsplit=1)[0]}]"
        )

    @property
    def count(self) -> str:
        """Access the ``trigger.timer[N].count`` attribute.

        **Description:**
            - This attribute sets the number of events to generate each time the timer generates a
              trigger event.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].count)`` query.
            - Setting this property to a value will send the ``trigger.timer[N].count = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].count = value
            - print(trigger.timer[N].count)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".count"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.count)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.count`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @count.setter
    def count(self, value: Union[str, float]) -> None:
        """Access the ``trigger.timer[N].count`` attribute.

        **Description:**
            - This attribute sets the number of events to generate each time the timer generates a
              trigger event.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].count)`` query.
            - Setting this property to a value will send the ``trigger.timer[N].count = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].count = value
            - print(trigger.timer[N].count)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".count", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.count = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.count`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def delay(self) -> str:
        """Access the ``trigger.timer[N].delay`` attribute.

        **Description:**
            - This attribute sets and reads the timer delay.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].delay)`` query.
            - Setting this property to a value will send the ``trigger.timer[N].delay = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].delay = value
            - print(trigger.timer[N].delay)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".delay"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.delay)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.delay`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @delay.setter
    def delay(self, value: Union[str, float]) -> None:
        """Access the ``trigger.timer[N].delay`` attribute.

        **Description:**
            - This attribute sets and reads the timer delay.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].delay)`` query.
            - Setting this property to a value will send the ``trigger.timer[N].delay = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].delay = value
            - print(trigger.timer[N].delay)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".delay", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.delay = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.delay`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def delaylist(self) -> str:
        """Access the ``trigger.timer[N].delaylist`` attribute.

        **Description:**
            - This attribute sets an array of timer intervals.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].delaylist)`` query.
            - Setting this property to a value will send the ``trigger.timer[N].delaylist = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].delaylist = value
            - print(trigger.timer[N].delaylist)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".delaylist"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.delaylist)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.delaylist`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @delaylist.setter
    def delaylist(self, value: Union[str, float]) -> None:
        """Access the ``trigger.timer[N].delaylist`` attribute.

        **Description:**
            - This attribute sets an array of timer intervals.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].delaylist)`` query.
            - Setting this property to a value will send the ``trigger.timer[N].delaylist = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].delaylist = value
            - print(trigger.timer[N].delaylist)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".delaylist", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.delaylist = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.delaylist`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def overrun(self) -> str:
        """Access the ``trigger.timer[N].overrun`` attribute.

        **Description:**
            - This attribute indicates if an event was ignored because of the event detector state.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].overrun)`` query.

        **TSP Syntax:**

        ::

            - print(trigger.timer[N].overrun)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".overrun"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.overrun)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.overrun`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def passthrough(self) -> str:
        """Access the ``trigger.timer[N].passthrough`` attribute.

        **Description:**
            - This attribute enables or disables the timer trigger pass-through mode.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].passthrough)`` query.
            - Setting this property to a value will send the
              ``trigger.timer[N].passthrough = value`` command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].passthrough = value
            - print(trigger.timer[N].passthrough)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".passthrough"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.passthrough)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.passthrough`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @passthrough.setter
    def passthrough(self, value: Union[str, float]) -> None:
        """Access the ``trigger.timer[N].passthrough`` attribute.

        **Description:**
            - This attribute enables or disables the timer trigger pass-through mode.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].passthrough)`` query.
            - Setting this property to a value will send the
              ``trigger.timer[N].passthrough = value`` command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].passthrough = value
            - print(trigger.timer[N].passthrough)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".passthrough", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.passthrough = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.passthrough`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def stimulus(self) -> str:
        """Access the ``trigger.timer[N].stimulus`` attribute.

        **Description:**
            - This attribute specifies which event starts the timer.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].stimulus)`` query.
            - Setting this property to a value will send the ``trigger.timer[N].stimulus = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].stimulus = value
            - print(trigger.timer[N].stimulus)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".stimulus"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.stimulus)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.stimulus`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @stimulus.setter
    def stimulus(self, value: Union[str, float]) -> None:
        """Access the ``trigger.timer[N].stimulus`` attribute.

        **Description:**
            - This attribute specifies which event starts the timer.

        **Usage:**
            - Accessing this property will send the ``print(trigger.timer[N].stimulus)`` query.
            - Setting this property to a value will send the ``trigger.timer[N].stimulus = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.timer[N].stimulus = value
            - print(trigger.timer[N].stimulus)

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".stimulus", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.stimulus = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.stimulus`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def clear(self) -> None:
        """Run the ``trigger.timer[N].clear()`` function.

        **Description:**
            - This function clears the timer event detector and overrun indicator for the specified
              trigger timer number.

        **TSP Syntax:**

        ::

            - trigger.timer[N].clear()

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.clear()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.clear()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def reset(self) -> None:
        """Run the ``trigger.timer[N].reset()`` function.

        **Description:**
            - This function resets some of the trigger timer settings to their factory defaults.

        **TSP Syntax:**

        ::

            - trigger.timer[N].reset()

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.reset()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.reset()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def wait(self, timeout: float) -> str:
        """Run the ``trigger.timer[N].wait()`` function.

        **Description:**
            - This function waits for a trigger.

        **TSP Syntax:**

        ::

            - trigger.timer[N].wait()

        Args:
            timeout: Maximum amount of time in seconds to wait for the trigger.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.wait({timeout}))"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.wait()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class TriggerGeneratorItem(ValidatedDynamicNumberCmd, BaseTSPCmd):
    """The ``trigger.generator[N]`` command tree.

    **Info:**
        - ``N``, the generator number (1 or 2).

    Constants:
        - ``.EVENT_ID``: The trigger event generated by the trigger event generator.

    Properties/methods:
        - ``.assert()``: The ``trigger.generator[N].assert()`` function.
    """

    EVENT_ID = "trigger.generator[N].EVENT_ID"
    """str: The trigger event generated by the trigger event generator."""

    def __init__(self, device: Optional["TSPDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        # pylint: disable=invalid-name
        self.EVENT_ID = self.EVENT_ID.replace(
            "[N]", f"[{self._cmd_syntax.rsplit('[', maxsplit=1)[-1].split(']', maxsplit=1)[0]}]"
        )

    def assert_(self) -> None:
        """Run the ``trigger.generator[N].assert()`` function.

        **Description:**
            - This function generates a trigger event.

        **TSP Syntax:**

        ::

            - trigger.generator[N].assert()

        **Info:**
            - ``N``, the generator number (1 or 2).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.assert()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.assert()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class TriggerBlenderItem(ValidatedDynamicNumberCmd, BaseTSPCmd):
    """The ``trigger.blender[N]`` command tree.

    **Info:**
        - ``N``, the blender number (up to six).

    Constants:
        - ``.EVENT_ID``: The trigger blender event number.

    Properties/methods:
        - ``.clear()``: The ``trigger.blender[N].clear()`` function.
        - ``.orenable``: The ``trigger.blender[N].orenable`` attribute.
        - ``.overrun``: The ``trigger.blender[N].overrun`` attribute.
        - ``.reset()``: The ``trigger.blender[N].reset()`` function.
        - ``.stimulus``: The ``trigger.blender[N].stimulus[M]`` attribute.
        - ``.wait()``: The ``trigger.blender[N].wait()`` function.
    """

    EVENT_ID = "trigger.blender[N].EVENT_ID"
    """str: The trigger blender event number."""

    def __init__(self, device: Optional["TSPDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        # pylint: disable=invalid-name
        self.EVENT_ID = self.EVENT_ID.replace(
            "[N]", f"[{self._cmd_syntax.rsplit('[', maxsplit=1)[-1].split(']', maxsplit=1)[0]}]"
        )
        self._stimulus: Dict[int, Union[str, float]] = DefaultDictDeviceCommunication(
            cmd_syntax=f"{self._cmd_syntax}.stimulus[{{key}}]",
            write_syntax=f"{self._cmd_syntax}.stimulus[{{key}}] = ",
            query_syntax=f"print({self._cmd_syntax}.stimulus[{{key}}])",
            device=self._device,
        )

    @property
    def orenable(self) -> str:
        """Access the ``trigger.blender[N].orenable`` attribute.

        **Description:**
            - This attribute selects whether the blender performs OR operations or AND operations.

        **Usage:**
            - Accessing this property will send the ``print(trigger.blender[N].orenable)`` query.
            - Setting this property to a value will send the ``trigger.blender[N].orenable = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.blender[N].orenable = value
            - print(trigger.blender[N].orenable)

        **Info:**
            - ``N``, the blender number (up to six).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".orenable"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.orenable)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.orenable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @orenable.setter
    def orenable(self, value: Union[str, float]) -> None:
        """Access the ``trigger.blender[N].orenable`` attribute.

        **Description:**
            - This attribute selects whether the blender performs OR operations or AND operations.

        **Usage:**
            - Accessing this property will send the ``print(trigger.blender[N].orenable)`` query.
            - Setting this property to a value will send the ``trigger.blender[N].orenable = value``
              command.

        **TSP Syntax:**

        ::

            - trigger.blender[N].orenable = value
            - print(trigger.blender[N].orenable)

        **Info:**
            - ``N``, the blender number (up to six).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".orenable", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.orenable = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.orenable`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def overrun(self) -> str:
        """Access the ``trigger.blender[N].overrun`` attribute.

        **Description:**
            - This attribute indicates whether or not an event was ignored because of the event
              detector state.

        **Usage:**
            - Accessing this property will send the ``print(trigger.blender[N].overrun)`` query.

        **TSP Syntax:**

        ::

            - print(trigger.blender[N].overrun)

        **Info:**
            - ``N``, the blender number (up to six).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".overrun"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.overrun)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.overrun`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def stimulus(self) -> Dict[int, Union[str, float]]:
        """Access the ``trigger.blender[N].stimulus[M]`` attribute.

        **Description:**
            - This attribute specifies the events that trigger the blender.

        **Usage:**
            - Accessing an item from this property will send the
              ``print(trigger.blender[N].stimulus[M])`` query.
            - Setting an item from this property to a value will send the
              ``trigger.blender[N].stimulus[M] = value`` command.

        **TSP Syntax:**

        ::

            - trigger.blender[N].stimulus[M] = value
            - print(trigger.blender[N].stimulus[M])

        **Info:**
            - ``N``, the an integer representing the trigger event blender (up to six).
            - ``M``, the an integer representing the stimulus index (1 to 4).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        return self._stimulus

    def clear(self) -> None:
        """Run the ``trigger.blender[N].clear()`` function.

        **Description:**
            - This function clears the blender event detector and resets the overrun indicator of
              blender N.

        **TSP Syntax:**

        ::

            - trigger.blender[N].clear()

        **Info:**
            - ``N``, the blender number (up to six).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.clear()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.clear()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def reset(self) -> None:
        """Run the ``trigger.blender[N].reset()`` function.

        **Description:**
            - This function resets some of the trigger blender settings to their factory defaults.

        **TSP Syntax:**

        ::

            - trigger.blender[N].reset()

        **Info:**
            - ``N``, the trigger event blender (up to six).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.reset()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.reset()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def wait(self, timeout: float) -> str:
        """Run the ``trigger.blender[N].wait()`` function.

        **Description:**
            - This function waits for a blender trigger event to occur.

        **TSP Syntax:**

        ::

            - trigger.blender[N].wait()

        Args:
            timeout: Maximum amount of time in seconds to wait for the trigger blender event.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.wait({timeout}))"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.wait()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class Trigger(BaseTSPCmd):
    """The ``trigger`` command tree.

    Constants:
        - ``.EVENT_ID``: The command interface trigger event number.

    Properties/methods:
        - ``.blender``: The ``trigger.blender[N]`` command tree.
        - ``.clear()``: The ``trigger.clear()`` function.
        - ``.generator``: The ``trigger.generator[N]`` command tree.
        - ``.timer``: The ``trigger.timer[N]`` command tree.
        - ``.wait()``: The ``trigger.wait()`` function.
    """

    EVENT_ID = "trigger.EVENT_ID"
    """str: The command interface trigger event number."""

    def __init__(self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "trigger") -> None:
        super().__init__(device, cmd_syntax)
        self._blender: Dict[int, TriggerBlenderItem] = DefaultDictPassKeyToFactory(
            lambda x: TriggerBlenderItem(device, f"{self._cmd_syntax}.blender[{x}]")
        )
        self._generator: Dict[int, TriggerGeneratorItem] = DefaultDictPassKeyToFactory(
            lambda x: TriggerGeneratorItem(device, f"{self._cmd_syntax}.generator[{x}]")
        )
        self._timer: Dict[int, TriggerTimerItem] = DefaultDictPassKeyToFactory(
            lambda x: TriggerTimerItem(device, f"{self._cmd_syntax}.timer[{x}]")
        )

    @property
    def blender(self) -> Dict[int, TriggerBlenderItem]:
        """Return the ``trigger.blender[N]`` command tree.

        **Info:**
            - ``N``, the blender number (up to six).

        Constants:
            - ``.EVENT_ID``: The trigger blender event number.

        Sub-properties/methods:
            - ``.clear()``: The ``trigger.blender[N].clear()`` function.
            - ``.orenable``: The ``trigger.blender[N].orenable`` attribute.
            - ``.overrun``: The ``trigger.blender[N].overrun`` attribute.
            - ``.reset()``: The ``trigger.blender[N].reset()`` function.
            - ``.stimulus``: The ``trigger.blender[N].stimulus[M]`` attribute.
            - ``.wait()``: The ``trigger.blender[N].wait()`` function.
        """
        return self._blender

    @property
    def generator(self) -> Dict[int, TriggerGeneratorItem]:
        """Return the ``trigger.generator[N]`` command tree.

        **Info:**
            - ``N``, the generator number (1 or 2).

        Constants:
            - ``.EVENT_ID``: The trigger event generated by the trigger event generator.

        Sub-properties/methods:
            - ``.assert()``: The ``trigger.generator[N].assert()`` function.
        """
        return self._generator

    @property
    def timer(self) -> Dict[int, TriggerTimerItem]:
        """Return the ``trigger.timer[N]`` command tree.

        **Info:**
            - ``N``, the trigger timer number (1 to 8).

        Constants:
            - ``.EVENT_ID``: The trigger timer event number.

        Sub-properties/methods:
            - ``.clear()``: The ``trigger.timer[N].clear()`` function.
            - ``.count``: The ``trigger.timer[N].count`` attribute.
            - ``.delay``: The ``trigger.timer[N].delay`` attribute.
            - ``.delaylist``: The ``trigger.timer[N].delaylist`` attribute.
            - ``.overrun``: The ``trigger.timer[N].overrun`` attribute.
            - ``.passthrough``: The ``trigger.timer[N].passthrough`` attribute.
            - ``.reset()``: The ``trigger.timer[N].reset()`` function.
            - ``.stimulus``: The ``trigger.timer[N].stimulus`` attribute.
            - ``.wait()``: The ``trigger.timer[N].wait()`` function.
        """
        return self._timer

    def clear(self) -> None:
        """Run the ``trigger.clear()`` function.

        **Description:**
            - This function clears the command interface trigger event detector.

        **TSP Syntax:**

        ::

            - trigger.clear()

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.clear()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.clear()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def wait(self, timeout: float) -> str:
        """Run the ``trigger.wait()`` function.

        **Description:**
            - This function waits for a command interface trigger event.

        **TSP Syntax:**

        ::

            - trigger.wait()

        Args:
            timeout: Maximum amount of time in seconds to wait for the trigger.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.wait({timeout}))"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.wait()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error



"""The configuration commands module.

These commands are used in the following models:
LPD6, MSO2, MSO4, MSO5, MSO5B, MSO5LP, MSO6, MSO6B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CONFIGuration:ANALOg:BANDWidth?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class ConfigurationAnalogBandwidth(SCPICmdRead):
    """The ``CONFIGuration:ANALOg:BANDWidth`` command.

    **Description:**
        - This command queries the maximum licensed bandwidth of the instrument.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:BANDWidth?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:BANDWidth?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONFIGuration:ANALOg:BANDWidth?
    """


class ConfigurationAnalog(SCPICmdRead):
    """The ``CONFIGuration:ANALOg`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.bandwidth``: The ``CONFIGuration:ANALOg:BANDWidth`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._bandwidth = ConfigurationAnalogBandwidth(device, f"{self._cmd_syntax}:BANDWidth")

    @property
    def bandwidth(self) -> ConfigurationAnalogBandwidth:
        """Return the ``CONFIGuration:ANALOg:BANDWidth`` command.

        **Description:**
            - This command queries the maximum licensed bandwidth of the instrument.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg:BANDWidth?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg:BANDWidth?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONFIGuration:ANALOg:BANDWidth?
        """
        return self._bandwidth


class Configuration(SCPICmdRead):
    """The ``CONFIGuration`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONFIGuration?`` query.
        - Using the ``.verify(value)`` method will send the ``CONFIGuration?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.analog``: The ``CONFIGuration:ANALOg`` command tree.
    """

    def __init__(
        self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CONFIGuration"
    ) -> None:
        super().__init__(device, cmd_syntax)
        self._analog = ConfigurationAnalog(device, f"{self._cmd_syntax}:ANALOg")

    @property
    def analog(self) -> ConfigurationAnalog:
        """Return the ``CONFIGuration:ANALOg`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONFIGuration:ANALOg?`` query.
            - Using the ``.verify(value)`` method will send the ``CONFIGuration:ANALOg?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.bandwidth``: The ``CONFIGuration:ANALOg:BANDWidth`` command.
        """
        return self._analog



"""DSA70KC device driver module."""
from tm_devices.commands import DSA70KCMixin
from tm_devices.drivers.pi.scopes.tekscope_5k_7k_70k.dsa70k import DSA70K


class DSA70KC(DSA70KCMixin, DSA70K):
    """DSA70KC device driver."""



"""The acquire commands module.

These commands are used in the following models:
DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO70KSX, DPO7KC, DSA70KC, DSA70KD, MSO5KB, MSO70KC, MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - ACQuire:ENHANCEDEnob {OFF|AUTO}
    - ACQuire:ENHANCEDEnob:STATE?
    - ACQuire:INTERPEightbit {AUTO|ON|OFF}
    - ACQuire:INTERPEightbit?
    - ACQuire:MAGnivu {<NR1>|OFF|ON}
    - ACQuire:MAGnivu?
    - ACQuire:MODe {SAMple|PEAKdetect|HIRes|AVErage|WFMDB|ENVelope}
    - ACQuire:MODe:ACTUal?
    - ACQuire:MODe?
    - ACQuire:NUMACq?
    - ACQuire:NUMAVg <NR1>
    - ACQuire:NUMAVg?
    - ACQuire:NUMEnv {<NR1>|INFInite}
    - ACQuire:NUMEnv?
    - ACQuire:NUMFRAMESACQuired?
    - ACQuire:NUMSAMples <NR1>
    - ACQuire:NUMSAMples?
    - ACQuire:SAMPlingmode {RT|ET|IT}
    - ACQuire:SAMPlingmode?
    - ACQuire:STATE {<NR1>|OFF|ON|RUN|STOP}
    - ACQuire:STATE?
    - ACQuire:STOPAfter {RUNSTop|SEQuence}
    - ACQuire:STOPAfter?
    - ACQuire:SYNcsamples {ON | OFF}
    - ACQuire:SYNcsamples?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class AcquireSyncsamples(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:SYNcsamples`` command.

    **Description:**
        - This command sets or queries whether the acquisition process is modified to sync up
          samples to trigger (for example, resample the waveform such that ttoff=0). This improves
          waveform jitter and skew in Average mode because each waveform is aligned to the trigger.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:SYNcsamples?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:SYNcsamples?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:SYNcsamples value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:SYNcsamples {ON | OFF}
        - ACQuire:SYNcsamples?

    **Info:**
        - ``ON`` sets the acquisition process to be modified to sync up samples to trigger.
        - ``OFF`` sets the system so that no modification of the acquisition process is performed.
    """


class AcquireStopafter(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:STOPAfter`` command.

    **Description:**
        - This command sets or queries whether the instrument continually acquires acquisitions or
          acquires a single sequence. Pressing SINGLE on the front panel button is equivalent to
          sending these commands: ``ACQUIRE:STOPAFTER SEQUENCE`` and ``ACQUIRE:STATE 1``.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:STOPAfter?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:STOPAfter?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:STOPAfter value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:STOPAfter {RUNSTop|SEQuence}
        - ACQuire:STOPAfter?

    **Info:**
        - ``RUNSTop`` specifies that the instrument will continually acquire data, if
          ``ACQuire:STATE`` is turned on.
        - ``SEQuence`` specifies that the next acquisition will be a single-sequence acquisition.
    """


class AcquireState(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:STATE`` command.

    **Description:**
        - This command starts or stops acquisitions. When state is set to ON or RUN, a new
          acquisition will be started. If the last acquisition was a single acquisition sequence, a
          new single sequence acquisition will be started. If the last acquisition was continuous, a
          new continuous acquisition will be started. If RUN is issued in the middle of completing a
          single sequence acquisition (for example, averaging or enveloping), the acquisition
          sequence is restarted, and any accumulated data is discarded. Also, the instrument resets
          the number of acquisitions. If the RUN argument is issued while in continuous mode, a
          reset occurs and acquired data continues to acquire. If ``acquire:stopafter`` is SEQUENCE,
          this command leaves the instrument in single sequence, unlike the run/stop button which
          takes the instrument out of single sequence.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:STATE?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:STATE?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:STATE value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:STATE {<NR1>|OFF|ON|RUN|STOP}
        - ACQuire:STATE?

    **Info:**
        - ``<NR1>`` = 0 stops acquisitions; any other value starts acquisitions.
        - ``OFF`` stops acquisitions.
        - ``ON`` starts acquisitions.
        - ``RUN`` starts acquisitions.
        - ``STOP`` stops acquisitions.
    """


class AcquireSamplingmode(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:SAMPlingmode`` command.

    **Description:**
        - This command sets or queries the sampling mode.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:SAMPlingmode?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:SAMPlingmode?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:SAMPlingmode value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:SAMPlingmode {RT|ET|IT}
        - ACQuire:SAMPlingmode?

    **Info:**
        - ``RT`` sets the sampling mode to real time only.
        - ``ET`` sets the sampling mode to equivalent time allowed (ON in REPET).
        - ``IT`` sets the sampling mode to interpolation allowed (OFF in REPET).
    """


class AcquireNumsamples(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:NUMSAMples`` command.

    **Description:**
        - This command sets or queries the minimum number of acquired samples that make up a
          waveform database (WfmDB) waveform for single sequence mode and Mask Pass/Fail Completion
          Test. This is equivalent to setting the Waveform Database Samples in the Acquisition Mode
          side menu.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:NUMSAMples?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:NUMSAMples?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:NUMSAMples value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:NUMSAMples <NR1>
        - ACQuire:NUMSAMples?

    **Info:**
        - ``<NR1>`` is the minimum number of acquired samples that make up a waveform database
          (WfmDB) waveform for single sequence mode and Mask Pass/Fail Completion Test. The default
          value is 16,000 samples. The range is 5,000 to 2,147,400,000 samples.
    """


class AcquireNumframesacquired(SCPICmdRead):
    """The ``ACQuire:NUMFRAMESACQuired`` command.

    **Description:**
        - This query returns the number of FastFrame frames which have been acquired.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:NUMFRAMESACQuired?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:NUMFRAMESACQuired?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ACQuire:NUMFRAMESACQuired?
    """


class AcquireNumenv(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:NUMEnv`` command.

    **Description:**
        - This command controls the number of envelopes (when acquisition mode has been set to
          ENVelope using ``ACQUIRE:MODE``). The number of envelopes can be set from 1 to 2000 in
          increments of 1, or to INFInite. Setting the value to a number greater than 2000 sets the
          number of envelopes to INFInite.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:NUMEnv?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:NUMEnv?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:NUMEnv value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:NUMEnv {<NR1>|INFInite}
        - ACQuire:NUMEnv?

    **Info:**
        - ``<NR1>`` is an integer that specifies the number of envelopes to use when the acquisition
          mode has been set to ENVelope.
        - ``INFInite`` specifies to use an infinite number of envelopes.
    """


class AcquireNumavg(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:NUMAVg`` command.

    **Description:**
        - This command sets or queries the number of waveform acquisitions that make up an averaged
          waveform. Ranges from 2 to 10240.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:NUMAVg?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:NUMAVg?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:NUMAVg value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:NUMAVg <NR1>
        - ACQuire:NUMAVg?

    **Info:**
        - ``<NR1>`` is the number of waveform acquisitions to average.
    """


class AcquireNumacq(SCPICmdRead):
    """The ``ACQuire:NUMACq`` command.

    **Description:**
        - This query-only command returns the number of waveform acquisitions that have occurred
          since the last time acquisitions were stopped.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:NUMACq?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:NUMACq?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ACQuire:NUMACq?
    """


class AcquireModeActual(SCPICmdRead):
    """The ``ACQuire:MODe:ACTUal`` command.

    **Description:**
        - This query returns the acquisition mode that the instrument is actually using for
          acquisitions, as opposed to the ``ACQuire:MODe`` query, which returns the currently
          selected acquisition mode. The acquisition mode that the instrument is using may differ
          from the selected mode in cases where the HIRes or PkDetect mode has been selected and the
          sample rate is greater than or equal to the base sampling rate (that is 6.25 Gs/s for 70K
          oscilloscopes and 5 Gs/s for 5K and 7K oscilloscopes). This is because the HIRes and
          PkDetect modes are not available at such high sampling rates. In these cases, the
          instrument uses sampling mode, and this query returns SAMPLe, regardless of the mode
          selected. In other words, when either HIRes or PkDetect mode has been selected, and the
          sample rate is greater than or equal to the base sampling rate (that is 6.25 Gs/s for 70K
          scopes and 5 Gs/s for 5K and 7K oscilloscopes), use the ``ACQUIRE:MODE`` query to
          determine the current mode selection; use ``ACQuire:MODe:ACTUal?`` to determine which mode
          the instrument is actually using. For other modes, use either query, as they will return
          the same mode.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:MODe:ACTUal?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:MODe:ACTUal?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ACQuire:MODe:ACTUal?
    """


class AcquireMode(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:MODe`` command.

    **Description:**
        - This command sets or queries the selected acquisition mode of the instrument. This affects
          all live waveforms. This command is equivalent to selecting Horizontal/Acquisition from
          the Horiz/Acq menu, and then choosing the desired mode from the Acquisition Mode group
          box. ``ACQuire:MODe`` is the desired acquisition mode. Waveforms are the displayed data
          point values taken from acquisition intervals. Each acquisition interval represents a time
          duration set by the horizontal scale (time per division). The instrument sampling system
          always samples at the maximum rate and so an acquisition interval can include more than
          one sample. The acquisition mode (which you set using this ``ACQuire:MODe`` command)
          determines how the final value of the acquisition interval is generated from the many data
          samples.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:MODe?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:MODe?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:MODe value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:MODe {SAMple|PEAKdetect|HIRes|AVErage|WFMDB|ENVelope}
        - ACQuire:MODe?

    **Info:**
        - ``SAMple`` specifies that the displayed data point value is the first sampled value that
          is taken during the acquisition interval. In sample mode, all waveform data has 8 bits of
          precision. You can request 16 bit data with a CURVE query but the lower-order 8 bits of
          data will be zero. SAMple is the default mode.
        - ``PEAKdetect`` specifies the display of high-low range of the samples taken from a single
          waveform acquisition. The high-low range is displayed as a vertical column that extends
          from the highest to the lowest value sampled during the acquisition interval. PEAKdetect
          mode can reveal the presence of aliasing or narrow spikes.
        - ``HIRes`` specifies Hi Res mode where the displayed data point value is the average of all
          the samples taken during the acquisition interval. This is a form of averaging, where the
          average comes from a single waveform acquisition. The number of samples taken during the
          acquisition interval determines the number of data values that compose the average.
        - ``AVErage`` specifies averaging mode, in which the resulting waveform shows an average of
          SAMple data points from several separate waveform acquisitions. The instrument processes
          the number of waveforms you specify into the acquired waveform, creating a running
          exponential average of the input signal. The number of waveform acquisitions that go into
          making up the average waveform is set or queried using the ``ACQUIRE:NUMENV`` command.
        - ``WFMDB`` (Waveform Database) mode acquires and displays a waveform pixmap. A pixmap is
          the accumulation of one or more acquisitions.
        - ``ENVelope`` specifies envelope mode, where the resulting waveform shows the PEAKdetect
          range of data points from several separate waveform acquisitions. The number of waveform
          acquisitions that go into making up the envelope waveform is set or queried using the
          ``ACQUIRE:NUMENV`` command.

    Properties:
        - ``.actual``: The ``ACQuire:MODe:ACTUal`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._actual = AcquireModeActual(device, f"{self._cmd_syntax}:ACTUal")

    @property
    def actual(self) -> AcquireModeActual:
        """Return the ``ACQuire:MODe:ACTUal`` command.

        **Description:**
            - This query returns the acquisition mode that the instrument is actually using for
              acquisitions, as opposed to the ``ACQuire:MODe`` query, which returns the currently
              selected acquisition mode. The acquisition mode that the instrument is using may
              differ from the selected mode in cases where the HIRes or PkDetect mode has been
              selected and the sample rate is greater than or equal to the base sampling rate (that
              is 6.25 Gs/s for 70K oscilloscopes and 5 Gs/s for 5K and 7K oscilloscopes). This is
              because the HIRes and PkDetect modes are not available at such high sampling rates. In
              these cases, the instrument uses sampling mode, and this query returns SAMPLe,
              regardless of the mode selected. In other words, when either HIRes or PkDetect mode
              has been selected, and the sample rate is greater than or equal to the base sampling
              rate (that is 6.25 Gs/s for 70K scopes and 5 Gs/s for 5K and 7K oscilloscopes), use
              the ``ACQUIRE:MODE`` query to determine the current mode selection; use
              ``ACQuire:MODe:ACTUal?`` to determine which mode the instrument is actually using. For
              other modes, use either query, as they will return the same mode.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:MODe:ACTUal?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:MODe:ACTUal?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ACQuire:MODe:ACTUal?
        """
        return self._actual


class AcquireMagnivu(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:MAGnivu`` command.

    **Description:**
        - Turns on the MagniVu feature, which provides up to 32 times signal detail for fast viewing
          of short events. This feature is not recommended for slow data formats such as RS-232.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:MAGnivu?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:MAGnivu?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:MAGnivu value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:MAGnivu {<NR1>|OFF|ON}
        - ACQuire:MAGnivu?

    **Info:**
        - ``<NR1> = 0`` disables the MagniVu feature; any other value turns this feature on.
        - ``ON`` enables the MagniVu feature.
        - ``OFF`` disables the MagniVu feature.
    """


class AcquireInterpeightbit(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:INTERPEightbit`` command.

    **Description:**
        - This command sets or queries the interpolation acquisition mode of the instrument.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:INTERPEightbit?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:INTERPEightbit?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:INTERPEightbit value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:INTERPEightbit {AUTO|ON|OFF}
        - ACQuire:INTERPEightbit?

    **Info:**
        - ``AUTO`` lets the instrument automatically select the interpolation acquisition mode.
        - ``ON`` turns on the eight bit interpolation mode.
        - ``OFF`` turns off the eight bit interpolation mode.
    """


class AcquireEnhancedenobState(SCPICmdRead):
    """The ``ACQuire:ENHANCEDEnob:STATE`` command.

    **Description:**
        - This command queries the state of the enhanced effective number of bits.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire:ENHANCEDEnob:STATE?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:ENHANCEDEnob:STATE?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ACQuire:ENHANCEDEnob:STATE?
    """


class AcquireEnhancedenob(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:ENHANCEDEnob`` command.

    **Description:**
        - This command sets or queries the state of the enhanced effective number of bits.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``ACQuire:ENHANCEDEnob value`` command.

    **SCPI Syntax:**

    ::

        - ACQuire:ENHANCEDEnob {OFF|AUTO}

    **Info:**
        - ``OFF`` turns off enhanced effective number of bits.
        - ``AUTO`` turns enhanced effective number of bits to AUTO.

    Properties:
        - ``.state``: The ``ACQuire:ENHANCEDEnob:STATE`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._state = AcquireEnhancedenobState(device, f"{self._cmd_syntax}:STATE")

    @property
    def state(self) -> AcquireEnhancedenobState:
        """Return the ``ACQuire:ENHANCEDEnob:STATE`` command.

        **Description:**
            - This command queries the state of the enhanced effective number of bits.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:ENHANCEDEnob:STATE?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:ENHANCEDEnob:STATE?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ACQuire:ENHANCEDEnob:STATE?
        """
        return self._state


#  pylint: disable=too-many-instance-attributes
class Acquire(SCPICmdRead):
    """The ``ACQuire`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``ACQuire?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.enhancedenob``: The ``ACQuire:ENHANCEDEnob`` command.
        - ``.interpeightbit``: The ``ACQuire:INTERPEightbit`` command.
        - ``.magnivu``: The ``ACQuire:MAGnivu`` command.
        - ``.mode``: The ``ACQuire:MODe`` command.
        - ``.numacq``: The ``ACQuire:NUMACq`` command.
        - ``.numavg``: The ``ACQuire:NUMAVg`` command.
        - ``.numenv``: The ``ACQuire:NUMEnv`` command.
        - ``.numframesacquired``: The ``ACQuire:NUMFRAMESACQuired`` command.
        - ``.numsamples``: The ``ACQuire:NUMSAMples`` command.
        - ``.samplingmode``: The ``ACQuire:SAMPlingmode`` command.
        - ``.state``: The ``ACQuire:STATE`` command.
        - ``.stopafter``: The ``ACQuire:STOPAfter`` command.
        - ``.syncsamples``: The ``ACQuire:SYNcsamples`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "ACQuire") -> None:
        super().__init__(device, cmd_syntax)
        self._enhancedenob = AcquireEnhancedenob(device, f"{self._cmd_syntax}:ENHANCEDEnob")
        self._interpeightbit = AcquireInterpeightbit(device, f"{self._cmd_syntax}:INTERPEightbit")
        self._magnivu = AcquireMagnivu(device, f"{self._cmd_syntax}:MAGnivu")
        self._mode = AcquireMode(device, f"{self._cmd_syntax}:MODe")
        self._numacq = AcquireNumacq(device, f"{self._cmd_syntax}:NUMACq")
        self._numavg = AcquireNumavg(device, f"{self._cmd_syntax}:NUMAVg")
        self._numenv = AcquireNumenv(device, f"{self._cmd_syntax}:NUMEnv")
        self._numframesacquired = AcquireNumframesacquired(
            device, f"{self._cmd_syntax}:NUMFRAMESACQuired"
        )
        self._numsamples = AcquireNumsamples(device, f"{self._cmd_syntax}:NUMSAMples")
        self._samplingmode = AcquireSamplingmode(device, f"{self._cmd_syntax}:SAMPlingmode")
        self._state = AcquireState(device, f"{self._cmd_syntax}:STATE")
        self._stopafter = AcquireStopafter(device, f"{self._cmd_syntax}:STOPAfter")
        self._syncsamples = AcquireSyncsamples(device, f"{self._cmd_syntax}:SYNcsamples")

    @property
    def enhancedenob(self) -> AcquireEnhancedenob:
        """Return the ``ACQuire:ENHANCEDEnob`` command.

        **Description:**
            - This command sets or queries the state of the enhanced effective number of bits.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``ACQuire:ENHANCEDEnob value``
              command.

        **SCPI Syntax:**

        ::

            - ACQuire:ENHANCEDEnob {OFF|AUTO}

        **Info:**
            - ``OFF`` turns off enhanced effective number of bits.
            - ``AUTO`` turns enhanced effective number of bits to AUTO.

        Sub-properties:
            - ``.state``: The ``ACQuire:ENHANCEDEnob:STATE`` command.
        """
        return self._enhancedenob

    @property
    def interpeightbit(self) -> AcquireInterpeightbit:
        """Return the ``ACQuire:INTERPEightbit`` command.

        **Description:**
            - This command sets or queries the interpolation acquisition mode of the instrument.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:INTERPEightbit?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:INTERPEightbit?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:INTERPEightbit value``
              command.

        **SCPI Syntax:**

        ::

            - ACQuire:INTERPEightbit {AUTO|ON|OFF}
            - ACQuire:INTERPEightbit?

        **Info:**
            - ``AUTO`` lets the instrument automatically select the interpolation acquisition mode.
            - ``ON`` turns on the eight bit interpolation mode.
            - ``OFF`` turns off the eight bit interpolation mode.
        """
        return self._interpeightbit

    @property
    def magnivu(self) -> AcquireMagnivu:
        """Return the ``ACQuire:MAGnivu`` command.

        **Description:**
            - Turns on the MagniVu feature, which provides up to 32 times signal detail for fast
              viewing of short events. This feature is not recommended for slow data formats such as
              RS-232.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:MAGnivu?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:MAGnivu?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:MAGnivu value`` command.

        **SCPI Syntax:**

        ::

            - ACQuire:MAGnivu {<NR1>|OFF|ON}
            - ACQuire:MAGnivu?

        **Info:**
            - ``<NR1> = 0`` disables the MagniVu feature; any other value turns this feature on.
            - ``ON`` enables the MagniVu feature.
            - ``OFF`` disables the MagniVu feature.
        """
        return self._magnivu

    @property
    def mode(self) -> AcquireMode:
        """Return the ``ACQuire:MODe`` command.

        **Description:**
            - This command sets or queries the selected acquisition mode of the instrument. This
              affects all live waveforms. This command is equivalent to selecting
              Horizontal/Acquisition from the Horiz/Acq menu, and then choosing the desired mode
              from the Acquisition Mode group box. ``ACQuire:MODe`` is the desired acquisition mode.
              Waveforms are the displayed data point values taken from acquisition intervals. Each
              acquisition interval represents a time duration set by the horizontal scale (time per
              division). The instrument sampling system always samples at the maximum rate and so an
              acquisition interval can include more than one sample. The acquisition mode (which you
              set using this ``ACQuire:MODe`` command) determines how the final value of the
              acquisition interval is generated from the many data samples.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:MODe?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:MODe?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:MODe value`` command.

        **SCPI Syntax:**

        ::

            - ACQuire:MODe {SAMple|PEAKdetect|HIRes|AVErage|WFMDB|ENVelope}
            - ACQuire:MODe?

        **Info:**
            - ``SAMple`` specifies that the displayed data point value is the first sampled value
              that is taken during the acquisition interval. In sample mode, all waveform data has 8
              bits of precision. You can request 16 bit data with a CURVE query but the lower-order
              8 bits of data will be zero. SAMple is the default mode.
            - ``PEAKdetect`` specifies the display of high-low range of the samples taken from a
              single waveform acquisition. The high-low range is displayed as a vertical column that
              extends from the highest to the lowest value sampled during the acquisition interval.
              PEAKdetect mode can reveal the presence of aliasing or narrow spikes.
            - ``HIRes`` specifies Hi Res mode where the displayed data point value is the average of
              all the samples taken during the acquisition interval. This is a form of averaging,
              where the average comes from a single waveform acquisition. The number of samples
              taken during the acquisition interval determines the number of data values that
              compose the average.
            - ``AVErage`` specifies averaging mode, in which the resulting waveform shows an average
              of SAMple data points from several separate waveform acquisitions. The instrument
              processes the number of waveforms you specify into the acquired waveform, creating a
              running exponential average of the input signal. The number of waveform acquisitions
              that go into making up the average waveform is set or queried using the
              ``ACQUIRE:NUMENV`` command.
            - ``WFMDB`` (Waveform Database) mode acquires and displays a waveform pixmap. A pixmap
              is the accumulation of one or more acquisitions.
            - ``ENVelope`` specifies envelope mode, where the resulting waveform shows the
              PEAKdetect range of data points from several separate waveform acquisitions. The
              number of waveform acquisitions that go into making up the envelope waveform is set or
              queried using the ``ACQUIRE:NUMENV`` command.

        Sub-properties:
            - ``.actual``: The ``ACQuire:MODe:ACTUal`` command.
        """
        return self._mode

    @property
    def numacq(self) -> AcquireNumacq:
        """Return the ``ACQuire:NUMACq`` command.

        **Description:**
            - This query-only command returns the number of waveform acquisitions that have occurred
              since the last time acquisitions were stopped.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:NUMACq?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:NUMACq?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ACQuire:NUMACq?
        """
        return self._numacq

    @property
    def numavg(self) -> AcquireNumavg:
        """Return the ``ACQuire:NUMAVg`` command.

        **Description:**
            - This command sets or queries the number of waveform acquisitions that make up an
              averaged waveform. Ranges from 2 to 10240.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:NUMAVg?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:NUMAVg?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:NUMAVg value`` command.

        **SCPI Syntax:**

        ::

            - ACQuire:NUMAVg <NR1>
            - ACQuire:NUMAVg?

        **Info:**
            - ``<NR1>`` is the number of waveform acquisitions to average.
        """
        return self._numavg

    @property
    def numenv(self) -> AcquireNumenv:
        """Return the ``ACQuire:NUMEnv`` command.

        **Description:**
            - This command controls the number of envelopes (when acquisition mode has been set to
              ENVelope using ``ACQUIRE:MODE``). The number of envelopes can be set from 1 to 2000 in
              increments of 1, or to INFInite. Setting the value to a number greater than 2000 sets
              the number of envelopes to INFInite.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:NUMEnv?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:NUMEnv?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:NUMEnv value`` command.

        **SCPI Syntax:**

        ::

            - ACQuire:NUMEnv {<NR1>|INFInite}
            - ACQuire:NUMEnv?

        **Info:**
            - ``<NR1>`` is an integer that specifies the number of envelopes to use when the
              acquisition mode has been set to ENVelope.
            - ``INFInite`` specifies to use an infinite number of envelopes.
        """
        return self._numenv

    @property
    def numframesacquired(self) -> AcquireNumframesacquired:
        """Return the ``ACQuire:NUMFRAMESACQuired`` command.

        **Description:**
            - This query returns the number of FastFrame frames which have been acquired.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:NUMFRAMESACQuired?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:NUMFRAMESACQuired?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ACQuire:NUMFRAMESACQuired?
        """
        return self._numframesacquired

    @property
    def numsamples(self) -> AcquireNumsamples:
        """Return the ``ACQuire:NUMSAMples`` command.

        **Description:**
            - This command sets or queries the minimum number of acquired samples that make up a
              waveform database (WfmDB) waveform for single sequence mode and Mask Pass/Fail
              Completion Test. This is equivalent to setting the Waveform Database Samples in the
              Acquisition Mode side menu.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:NUMSAMples?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:NUMSAMples?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:NUMSAMples value`` command.

        **SCPI Syntax:**

        ::

            - ACQuire:NUMSAMples <NR1>
            - ACQuire:NUMSAMples?

        **Info:**
            - ``<NR1>`` is the minimum number of acquired samples that make up a waveform database
              (WfmDB) waveform for single sequence mode and Mask Pass/Fail Completion Test. The
              default value is 16,000 samples. The range is 5,000 to 2,147,400,000 samples.
        """
        return self._numsamples

    @property
    def samplingmode(self) -> AcquireSamplingmode:
        """Return the ``ACQuire:SAMPlingmode`` command.

        **Description:**
            - This command sets or queries the sampling mode.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:SAMPlingmode?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:SAMPlingmode?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:SAMPlingmode value``
              command.

        **SCPI Syntax:**

        ::

            - ACQuire:SAMPlingmode {RT|ET|IT}
            - ACQuire:SAMPlingmode?

        **Info:**
            - ``RT`` sets the sampling mode to real time only.
            - ``ET`` sets the sampling mode to equivalent time allowed (ON in REPET).
            - ``IT`` sets the sampling mode to interpolation allowed (OFF in REPET).
        """
        return self._samplingmode

    @property
    def state(self) -> AcquireState:
        """Return the ``ACQuire:STATE`` command.

        **Description:**
            - This command starts or stops acquisitions. When state is set to ON or RUN, a new
              acquisition will be started. If the last acquisition was a single acquisition
              sequence, a new single sequence acquisition will be started. If the last acquisition
              was continuous, a new continuous acquisition will be started. If RUN is issued in the
              middle of completing a single sequence acquisition (for example, averaging or
              enveloping), the acquisition sequence is restarted, and any accumulated data is
              discarded. Also, the instrument resets the number of acquisitions. If the RUN argument
              is issued while in continuous mode, a reset occurs and acquired data continues to
              acquire. If ``acquire:stopafter`` is SEQUENCE, this command leaves the instrument in
              single sequence, unlike the run/stop button which takes the instrument out of single
              sequence.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:STATE?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:STATE?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:STATE value`` command.

        **SCPI Syntax:**

        ::

            - ACQuire:STATE {<NR1>|OFF|ON|RUN|STOP}
            - ACQuire:STATE?

        **Info:**
            - ``<NR1>`` = 0 stops acquisitions; any other value starts acquisitions.
            - ``OFF`` stops acquisitions.
            - ``ON`` starts acquisitions.
            - ``RUN`` starts acquisitions.
            - ``STOP`` stops acquisitions.
        """
        return self._state

    @property
    def stopafter(self) -> AcquireStopafter:
        """Return the ``ACQuire:STOPAfter`` command.

        **Description:**
            - This command sets or queries whether the instrument continually acquires acquisitions
              or acquires a single sequence. Pressing SINGLE on the front panel button is equivalent
              to sending these commands: ``ACQUIRE:STOPAFTER SEQUENCE`` and ``ACQUIRE:STATE 1``.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:STOPAfter?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:STOPAfter?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:STOPAfter value`` command.

        **SCPI Syntax:**

        ::

            - ACQuire:STOPAfter {RUNSTop|SEQuence}
            - ACQuire:STOPAfter?

        **Info:**
            - ``RUNSTop`` specifies that the instrument will continually acquire data, if
              ``ACQuire:STATE`` is turned on.
            - ``SEQuence`` specifies that the next acquisition will be a single-sequence
              acquisition.
        """
        return self._stopafter

    @property
    def syncsamples(self) -> AcquireSyncsamples:
        """Return the ``ACQuire:SYNcsamples`` command.

        **Description:**
            - This command sets or queries whether the acquisition process is modified to sync up
              samples to trigger (for example, resample the waveform such that ttoff=0). This
              improves waveform jitter and skew in Average mode because each waveform is aligned to
              the trigger.

        **Usage:**
            - Using the ``.query()`` method will send the ``ACQuire:SYNcsamples?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:SYNcsamples?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:SYNcsamples value``
              command.

        **SCPI Syntax:**

        ::

            - ACQuire:SYNcsamples {ON | OFF}
            - ACQuire:SYNcsamples?

        **Info:**
            - ``ON`` sets the acquisition process to be modified to sync up samples to trigger.
            - ``OFF`` sets the system so that no modification of the acquisition process is
              performed.
        """
        return self._syncsamples



# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The digio commands module.

These commands are used in the following models: SMU2601B_Pulse

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.
"""
from typing import Dict, Optional, TYPE_CHECKING

from .._helpers import (
    BaseTSPCmd,
    DefaultDictPassKeyToFactory,
    ValidatedDynamicNumberCmd,
)

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


# pylint: disable=too-few-public-methods
class DigioTriggerItem(ValidatedDynamicNumberCmd, BaseTSPCmd):
    """The ``digio.trigger[N]`` command tree.

    Constants:
        - ``.EVENT_ID``: Selects the event that causes a trigger to be asserted on the digital
          output line as the edge detected on the specified digital I/O line.
    """

    EVENT_ID = "digio.trigger[N].EVENT_ID"
    """str: Selects the event that causes a trigger to be asserted on the digital output line as the edge detected on the specified digital I/O line."""  # noqa: E501

    def __init__(self, device: Optional["TSPDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        # pylint: disable=invalid-name
        self.EVENT_ID = self.EVENT_ID.replace(
            "[N]", f"[{self._cmd_syntax.rsplit('[', maxsplit=1)[-1].split(']', maxsplit=1)[0]}]"
        )


class Digio(BaseTSPCmd):
    """The ``digio`` command tree.

    Constants:
        - ``.TRIG_BYPASS``: Sets the mode in which the trigger event detector and the output trigger
          generator operate on the specified trigger line to allow direct control of the line.
        - ``.TRIG_EITHER``: Sets the mode in which the trigger event detector and the output trigger
          generator operate on the specified trigger line to detect rising- or falling-edge triggers
          as input and assert a TTL-low pulse for output.
        - ``.TRIG_FALLING``: Sets the mode in which the trigger event detector and the output
          trigger generator operate on the specified trigger line to detect falling-edge triggers as
          input and assert a TTL-low pulse for output.
        - ``.TRIG_RISING``: Sets the mode in which the trigger event detector and the output trigger
          generator operate on the specified trigger line so that if the programmed state of the
          line is high, the digio.TRIG_RISING mode behavior is similar to digio.TRIG_RISINGA. If the
          programmed state of the line is low, the digio.TRIG_RISING mode behavior is similar to
          digio.TRIG_RISINGM. Only use this setting if necessary for compatibility with other
          Keithley Instruments products.
        - ``.TRIG_RISINGA``: Sets the mode in which the trigger event detector and the output
          trigger generator operate on the specified trigger line to detect rising-edge triggers as
          input and assert a TTL-low pulse for output.
        - ``.TRIG_RISINGM``: Sets the mode in which the trigger event detector and the output
          trigger generator operate on the specified trigger line to assert a TTL-high pulse for
          output. Input edge detection is not possible in this mode.
        - ``.TRIG_SYNCHRONOUS``: Sets the mode in which the trigger event detector and the output
          trigger generator operate on the specified trigger line to detect the falling-edge input
          triggers and automatically latch and drive the trigger line low. Asserts a TTL-low pulse
          as an output trigger.
        - ``.TRIG_SYNCHRONOUSA``: Sets the mode in which the trigger event detector and the output
          trigger generator operate on the specified trigger line to detect the falling-edge input
          triggers and automatically latch and drive the trigger line low. Asserting the output
          trigger releases the latched line.
        - ``.TRIG_SYNCHRONOUSM``: Sets the mode in which the trigger event detector and the output
          trigger generator operate on the specified trigger line to detect rising-edge triggers as
          input and assert a TTL-low pulse for output.

    Properties/methods:
        - ``.trigger``: The ``digio.trigger[N]`` command tree.
    """

    TRIG_BYPASS = "digio.TRIG_BYPASS"
    """str: Sets the mode in which the trigger event detector and the output trigger generator operate on the specified trigger line to allow direct control of the line."""  # noqa: E501
    TRIG_EITHER = "digio.TRIG_EITHER"
    """str: Sets the mode in which the trigger event detector and the output trigger generator operate on the specified trigger line to detect rising- or falling-edge triggers as input and assert a TTL-low pulse for output."""  # noqa: E501
    TRIG_FALLING = "digio.TRIG_FALLING"
    """str: Sets the mode in which the trigger event detector and the output trigger generator operate on the specified trigger line to detect falling-edge triggers as input and assert a TTL-low pulse for output."""  # noqa: E501
    TRIG_RISING = "digio.TRIG_RISING"
    """str: Sets the mode in which the trigger event detector and the output trigger generator operate on the specified trigger line so that if the programmed state of the line is high, the digio.TRIG_RISING mode behavior is similar to digio.TRIG_RISINGA. If the programmed state of the line is low, the digio.TRIG_RISING mode behavior is similar to digio.TRIG_RISINGM. Only use this setting if necessary for compatibility with other Keithley Instruments products."""  # noqa: E501
    TRIG_RISINGA = "digio.TRIG_RISINGA"
    """str: Sets the mode in which the trigger event detector and the output trigger generator operate on the specified trigger line to detect rising-edge triggers as input and assert a TTL-low pulse for output."""  # noqa: E501
    TRIG_RISINGM = "digio.TRIG_RISINGM"
    """str: Sets the mode in which the trigger event detector and the output trigger generator operate on the specified trigger line to assert a TTL-high pulse for output. Input edge detection is not possible in this mode."""  # noqa: E501
    TRIG_SYNCHRONOUS = "digio.TRIG_SYNCHRONOUS"
    """str: Sets the mode in which the trigger event detector and the output trigger generator operate on the specified trigger line to detect the falling-edge input triggers and automatically latch and drive the trigger line low. Asserts a TTL-low pulse as an output trigger."""  # noqa: E501
    TRIG_SYNCHRONOUSA = "digio.TRIG_SYNCHRONOUSA"
    """str: Sets the mode in which the trigger event detector and the output trigger generator operate on the specified trigger line to detect the falling-edge input triggers and automatically latch and drive the trigger line low. Asserting the output trigger releases the latched line."""  # noqa: E501
    TRIG_SYNCHRONOUSM = "digio.TRIG_SYNCHRONOUSM"
    """str: Sets the mode in which the trigger event detector and the output trigger generator operate on the specified trigger line to detect rising-edge triggers as input and assert a TTL-low pulse for output."""  # noqa: E501

    def __init__(self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "digio") -> None:
        super().__init__(device, cmd_syntax)
        self._trigger: Dict[int, DigioTriggerItem] = DefaultDictPassKeyToFactory(
            lambda x: DigioTriggerItem(device, f"{self._cmd_syntax}.trigger[{x}]")
        )

    @property
    def trigger(self) -> Dict[int, DigioTriggerItem]:
        """Return the ``digio.trigger[N]`` command tree.

        Constants:
            - ``.EVENT_ID``: Selects the event that causes a trigger to be asserted on the digital
              output line as the edge detected on the specified digital I/O line.
        """
        return self._trigger



"""The zoom commands module.

These commands are used in the following models:
DPO4K, DPO4KB, MDO3, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO4K, MSO4KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - ZOOm:MODe {ON|OFF|<NR1>}
    - ZOOm:STATE {ON|OFF|<NR1>}
    - ZOOm:ZOOM1:FACtor?
    - ZOOm:ZOOM1:HORizontal:POSition <NR3>
    - ZOOm:ZOOM1:HORizontal:POSition?
    - ZOOm:ZOOM1:HORizontal:SCAle <NR3>
    - ZOOm:ZOOM1:HORizontal:SCAle?
    - ZOOm:ZOOM1:POSition <NR3>
    - ZOOm:ZOOM1:POSition?
    - ZOOm:ZOOM1:SCAle <NR3>
    - ZOOm:ZOOM1:SCAle?
    - ZOOm:ZOOM1:STATE {ON|OFF|<NR1>}
    - ZOOm:ZOOM1:STATE?
    - ZOOm:ZOOM1:TRIGPOS?
    - ZOOm:ZOOM1?
    - ZOOm?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class ZoomZoom1Trigpos(SCPICmdRead):
    """The ``ZOOm:ZOOM1:TRIGPOS`` command.

    **Description:**
        - This query returns the time at the center of the zoom box relative to the trigger position
          of the currently selected time domain waveform.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:TRIGPOS?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:TRIGPOS?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ZOOm:ZOOM1:TRIGPOS?
    """


class ZoomZoom1State(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:STATE`` command.

    **Description:**
        - This command turns the specified zoom on or off. <x> can only be 1.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:STATE?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:STATE?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:STATE value`` command.

    **SCPI Syntax:**

    ::

        - ZOOm:ZOOM1:STATE {ON|OFF|<NR1>}
        - ZOOm:ZOOM1:STATE?

    **Info:**
        - ``ON`` turns Zoom 1 on.
        - ``OFF`` turns Zoom 1 off.
        - ``<NR1>`` is an integer. 0 disables the specified zoom; any other value enables the
          specified zoom.
    """


class ZoomZoom1Scale(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:SCAle`` command.

    **Description:**
        - This command specifies the horizontal scale of the zoom box. <x> can only be 1.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:SCAle?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:SCAle?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:SCAle value`` command.

    **SCPI Syntax:**

    ::

        - ZOOm:ZOOM1:SCAle <NR3>
        - ZOOm:ZOOM1:SCAle?

    **Info:**
        - ``<NR3>`` is a floating point number that specifies the horizontal scale of the zoom box.
    """


class ZoomZoom1Position(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:POSition`` command.

    **Description:**
        - Sets the horizontal position of the zoom box, in terms of 0 to 100.0% of upper window. <x>
          can only be 1.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:POSition?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:POSition?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:POSition value`` command.

    **SCPI Syntax:**

    ::

        - ZOOm:ZOOM1:POSition <NR3>
        - ZOOm:ZOOM1:POSition?

    **Info:**
        - ``<NR3>`` is a floating point number that specifies the horizontal position as a percent
          of the upper window.
    """


class ZoomZoom1HorizontalScale(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:HORizontal:SCAle`` command.

    **Description:**
        - This command specifies the zoom horizontal scale factor for the specified zoom, where x is
          the integer 1 representing the single zoom window. <x> can only be 1.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle value``
          command.

    **SCPI Syntax:**

    ::

        - ZOOm:ZOOM1:HORizontal:SCAle <NR3>
        - ZOOm:ZOOM1:HORizontal:SCAle?

    **Info:**
        - ``<NR3>`` is the amount of expansion in the horizontal direction in 1-2 -5 increments.
    """


class ZoomZoom1HorizontalPosition(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:HORizontal:POSition`` command.

    **Description:**
        - This command specifies the horizontal position for the specified zoom, where x is the
          integer 1 representing the single zoom window. <x> can only be 1.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition?``
          query and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition value``
          command.

    **SCPI Syntax:**

    ::

        - ZOOm:ZOOM1:HORizontal:POSition <NR3>
        - ZOOm:ZOOM1:HORizontal:POSition?

    **Info:**
        - ``<NR3>`` is a value from 0 to 100.00 and is the percent of the upper window that is to
          the left of screen center, when the zoom factor is 1× or greater.
    """


class ZoomZoom1Horizontal(SCPICmdRead):
    """The ``ZOOm:ZOOM1:HORizontal`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.position``: The ``ZOOm:ZOOM1:HORizontal:POSition`` command.
        - ``.scale``: The ``ZOOm:ZOOM1:HORizontal:SCAle`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._position = ZoomZoom1HorizontalPosition(device, f"{self._cmd_syntax}:POSition")
        self._scale = ZoomZoom1HorizontalScale(device, f"{self._cmd_syntax}:SCAle")

    @property
    def position(self) -> ZoomZoom1HorizontalPosition:
        """Return the ``ZOOm:ZOOM1:HORizontal:POSition`` command.

        **Description:**
            - This command specifies the horizontal position for the specified zoom, where x is the
              integer 1 representing the single zoom window. <x> can only be 1.

        **Usage:**
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``ZOOm:ZOOM1:HORizontal:POSition value`` command.

        **SCPI Syntax:**

        ::

            - ZOOm:ZOOM1:HORizontal:POSition <NR3>
            - ZOOm:ZOOM1:HORizontal:POSition?

        **Info:**
            - ``<NR3>`` is a value from 0 to 100.00 and is the percent of the upper window that is
              to the left of screen center, when the zoom factor is 1× or greater.
        """
        return self._position

    @property
    def scale(self) -> ZoomZoom1HorizontalScale:
        """Return the ``ZOOm:ZOOM1:HORizontal:SCAle`` command.

        **Description:**
            - This command specifies the zoom horizontal scale factor for the specified zoom, where
              x is the integer 1 representing the single zoom window. <x> can only be 1.

        **Usage:**
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle value``
              command.

        **SCPI Syntax:**

        ::

            - ZOOm:ZOOM1:HORizontal:SCAle <NR3>
            - ZOOm:ZOOM1:HORizontal:SCAle?

        **Info:**
            - ``<NR3>`` is the amount of expansion in the horizontal direction in 1-2 -5 increments.
        """
        return self._scale


class ZoomZoom1Factor(SCPICmdRead):
    """The ``ZOOm:ZOOM1:FACtor`` command.

    **Description:**
        - Returns the zoom factor of a particular zoom box. <x> can only be 1.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:FACtor?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:FACtor?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ZOOm:ZOOM1:FACtor?
    """


class ZoomZoom1(SCPICmdRead):
    """The ``ZOOm:ZOOM1`` command.

    **Description:**
        - Returns the current vertical and horizontal positioning and scaling of the display. <x>
          can only be 1.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ZOOm:ZOOM1?

    Properties:
        - ``.factor``: The ``ZOOm:ZOOM1:FACtor`` command.
        - ``.horizontal``: The ``ZOOm:ZOOM1:HORizontal`` command tree.
        - ``.position``: The ``ZOOm:ZOOM1:POSition`` command.
        - ``.scale``: The ``ZOOm:ZOOM1:SCAle`` command.
        - ``.state``: The ``ZOOm:ZOOM1:STATE`` command.
        - ``.trigpos``: The ``ZOOm:ZOOM1:TRIGPOS`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._factor = ZoomZoom1Factor(device, f"{self._cmd_syntax}:FACtor")
        self._horizontal = ZoomZoom1Horizontal(device, f"{self._cmd_syntax}:HORizontal")
        self._position = ZoomZoom1Position(device, f"{self._cmd_syntax}:POSition")
        self._scale = ZoomZoom1Scale(device, f"{self._cmd_syntax}:SCAle")
        self._state = ZoomZoom1State(device, f"{self._cmd_syntax}:STATE")
        self._trigpos = ZoomZoom1Trigpos(device, f"{self._cmd_syntax}:TRIGPOS")

    @property
    def factor(self) -> ZoomZoom1Factor:
        """Return the ``ZOOm:ZOOM1:FACtor`` command.

        **Description:**
            - Returns the zoom factor of a particular zoom box. <x> can only be 1.

        **Usage:**
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:FACtor?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:FACtor?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ZOOm:ZOOM1:FACtor?
        """
        return self._factor

    @property
    def horizontal(self) -> ZoomZoom1Horizontal:
        """Return the ``ZOOm:ZOOM1:HORizontal`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.position``: The ``ZOOm:ZOOM1:HORizontal:POSition`` command.
            - ``.scale``: The ``ZOOm:ZOOM1:HORizontal:SCAle`` command.
        """
        return self._horizontal

    @property
    def position(self) -> ZoomZoom1Position:
        """Return the ``ZOOm:ZOOM1:POSition`` command.

        **Description:**
            - Sets the horizontal position of the zoom box, in terms of 0 to 100.0% of upper window.
              <x> can only be 1.

        **Usage:**
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:POSition?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:POSition?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:POSition value``
              command.

        **SCPI Syntax:**

        ::

            - ZOOm:ZOOM1:POSition <NR3>
            - ZOOm:ZOOM1:POSition?

        **Info:**
            - ``<NR3>`` is a floating point number that specifies the horizontal position as a
              percent of the upper window.
        """
        return self._position

    @property
    def scale(self) -> ZoomZoom1Scale:
        """Return the ``ZOOm:ZOOM1:SCAle`` command.

        **Description:**
            - This command specifies the horizontal scale of the zoom box. <x> can only be 1.

        **Usage:**
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:SCAle?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:SCAle?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:SCAle value`` command.

        **SCPI Syntax:**

        ::

            - ZOOm:ZOOM1:SCAle <NR3>
            - ZOOm:ZOOM1:SCAle?

        **Info:**
            - ``<NR3>`` is a floating point number that specifies the horizontal scale of the zoom
              box.
        """
        return self._scale

    @property
    def state(self) -> ZoomZoom1State:
        """Return the ``ZOOm:ZOOM1:STATE`` command.

        **Description:**
            - This command turns the specified zoom on or off. <x> can only be 1.

        **Usage:**
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:STATE?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:STATE?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:STATE value`` command.

        **SCPI Syntax:**

        ::

            - ZOOm:ZOOM1:STATE {ON|OFF|<NR1>}
            - ZOOm:ZOOM1:STATE?

        **Info:**
            - ``ON`` turns Zoom 1 on.
            - ``OFF`` turns Zoom 1 off.
            - ``<NR1>`` is an integer. 0 disables the specified zoom; any other value enables the
              specified zoom.
        """
        return self._state

    @property
    def trigpos(self) -> ZoomZoom1Trigpos:
        """Return the ``ZOOm:ZOOM1:TRIGPOS`` command.

        **Description:**
            - This query returns the time at the center of the zoom box relative to the trigger
              position of the currently selected time domain waveform.

        **Usage:**
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:TRIGPOS?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:TRIGPOS?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ZOOm:ZOOM1:TRIGPOS?
        """
        return self._trigpos


class ZoomState(SCPICmdWrite):
    """The ``ZOOm:STATE`` command.

    **Description:**
        - Turns Zoom mode on or off. The Zoom query returns the current state of Zoom mode. This
          command is equivalent to pressing the zoom button located on the front panel.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``ZOOm:STATE value`` command.

    **SCPI Syntax:**

    ::

        - ZOOm:STATE {ON|OFF|<NR1>}

    **Info:**
        - ``ON`` turns on Zoom mode.
        - ``OFF`` turns off Zoom mode.
        - ``<NR1>`` is an integer. 0 turns off Zoom mode; any other value turns on Zoom mode.
    """


class ZoomMode(SCPICmdWrite):
    """The ``ZOOm:MODe`` command.

    **Description:**
        - Turns Zoom mode on or off. The Zoom query returns the current state of Zoom mode. This
          command is equivalent to pressing the zoom button located on the front panel.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``ZOOm:MODe value`` command.

    **SCPI Syntax:**

    ::

        - ZOOm:MODe {ON|OFF|<NR1>}

    **Info:**
        - ``ON`` turns on Zoom mode.
        - ``OFF`` turns off Zoom mode.
        - ``<NR1>`` is an integer. 0 turns off Zoom mode; any other value turns on Zoom mode.
    """


class Zoom(SCPICmdRead):
    """The ``ZOOm`` command.

    **Description:**
        - Returns the current vertical and horizontal positioning and scaling of the display.

    **Usage:**
        - Using the ``.query()`` method will send the ``ZOOm?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ZOOm?

    Properties:
        - ``.zoom1``: The ``ZOOm:ZOOM1`` command.
        - ``.mode``: The ``ZOOm:MODe`` command.
        - ``.state``: The ``ZOOm:STATE`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "ZOOm") -> None:
        super().__init__(device, cmd_syntax)
        self._zoom1 = ZoomZoom1(device, f"{self._cmd_syntax}:ZOOM1")
        self._mode = ZoomMode(device, f"{self._cmd_syntax}:MODe")
        self._state = ZoomState(device, f"{self._cmd_syntax}:STATE")

    @property
    def zoom1(self) -> ZoomZoom1:
        """Return the ``ZOOm:ZOOM1`` command.

        **Description:**
            - Returns the current vertical and horizontal positioning and scaling of the display.
              <x> can only be 1.

        **Usage:**
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ZOOm:ZOOM1?

        Sub-properties:
            - ``.factor``: The ``ZOOm:ZOOM1:FACtor`` command.
            - ``.horizontal``: The ``ZOOm:ZOOM1:HORizontal`` command tree.
            - ``.position``: The ``ZOOm:ZOOM1:POSition`` command.
            - ``.scale``: The ``ZOOm:ZOOM1:SCAle`` command.
            - ``.state``: The ``ZOOm:ZOOM1:STATE`` command.
            - ``.trigpos``: The ``ZOOm:ZOOM1:TRIGPOS`` command.
        """
        return self._zoom1

    @property
    def mode(self) -> ZoomMode:
        """Return the ``ZOOm:MODe`` command.

        **Description:**
            - Turns Zoom mode on or off. The Zoom query returns the current state of Zoom mode. This
              command is equivalent to pressing the zoom button located on the front panel.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``ZOOm:MODe value`` command.

        **SCPI Syntax:**

        ::

            - ZOOm:MODe {ON|OFF|<NR1>}

        **Info:**
            - ``ON`` turns on Zoom mode.
            - ``OFF`` turns off Zoom mode.
            - ``<NR1>`` is an integer. 0 turns off Zoom mode; any other value turns on Zoom mode.
        """
        return self._mode

    @property
    def state(self) -> ZoomState:
        """Return the ``ZOOm:STATE`` command.

        **Description:**
            - Turns Zoom mode on or off. The Zoom query returns the current state of Zoom mode. This
              command is equivalent to pressing the zoom button located on the front panel.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``ZOOm:STATE value`` command.

        **SCPI Syntax:**

        ::

            - ZOOm:STATE {ON|OFF|<NR1>}

        **Info:**
            - ``ON`` turns on Zoom mode.
            - ``OFF`` turns off Zoom mode.
            - ``<NR1>`` is an integer. 0 turns off Zoom mode; any other value turns on Zoom mode.
        """
        return self._state



"""SMU Model 2606B device driver module."""
from tm_devices.commands import SMU2606BMixin
from tm_devices.drivers.pi.source_measure_units.smu2600.smu2600b import SMU2600B


class SMU2606B(SMU2606BMixin, SMU2600B):
    """SMU2606B device driver."""



"""The deskew commands module.

These commands are used in the following models:
DPO4K, DPO4KB, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO4K, MSO4KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - DESkew {SETALLtorec}
    - DESkew:DISPlay {OFF|ON|0|1}
    - DESkew:DISPlay?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class DeskewDisplay(SCPICmdWrite, SCPICmdRead):
    """The ``DESkew:DISPlay`` command.

    **Description:**
        - This command specifies the state of the deskew table display.

    **Usage:**
        - Using the ``.query()`` method will send the ``DESkew:DISPlay?`` query.
        - Using the ``.verify(value)`` method will send the ``DESkew:DISPlay?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``DESkew:DISPlay value`` command.

    **SCPI Syntax:**

    ::

        - DESkew:DISPlay {OFF|ON|0|1}
        - DESkew:DISPlay?

    **Info:**
        - ``OFF`` or 0 turns off the deskew table display.
        - ``ON`` or 1 turns on the deskew table display.
    """


class Deskew(SCPICmdWrite, SCPICmdRead):
    """The ``DESkew`` command.

    **Description:**
        - Causes the deskew values for all channels to be set to the recommended values. Equivalent
          to pressing the 'Set all deskews to recommended values' button in the application UI.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``DESkew value`` command.

    **SCPI Syntax:**

    ::

        - DESkew {SETALLtorec}

    **Info:**
        - ``<SETALLtorec>`` sets the deskew for all channels to the recommended values.

    Properties:
        - ``.display``: The ``DESkew:DISPlay`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "DESkew") -> None:
        super().__init__(device, cmd_syntax)
        self._display = DeskewDisplay(device, f"{self._cmd_syntax}:DISPlay")

    @property
    def display(self) -> DeskewDisplay:
        """Return the ``DESkew:DISPlay`` command.

        **Description:**
            - This command specifies the state of the deskew table display.

        **Usage:**
            - Using the ``.query()`` method will send the ``DESkew:DISPlay?`` query.
            - Using the ``.verify(value)`` method will send the ``DESkew:DISPlay?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``DESkew:DISPlay value`` command.

        **SCPI Syntax:**

        ::

            - DESkew:DISPlay {OFF|ON|0|1}
            - DESkew:DISPlay?

        **Info:**
            - ``OFF`` or 0 turns off the deskew table display.
            - ``ON`` or 1 turns on the deskew table display.
        """
        return self._display



# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The eventlog commands module.

These commands are used in the following models: SMU2601B_Pulse

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import BaseTSPCmd

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


# pylint: disable=too-few-public-methods
class Eventlog(BaseTSPCmd):
    """The ``eventlog`` command tree.

    Constants:
        - ``.DISABLE``: Disable the event log.
        - ``.DISCARD_NEWEST``: Do not log new entries.
        - ``.DISCARD_OLDEST``: Delete old entries are deleted as new events are logged.
        - ``.ENABLE``: Enable the event log.
    """

    DISABLE = "eventlog.DISABLE"
    """str: Disable the event log."""
    DISCARD_NEWEST = "eventlog.DISCARD_NEWEST"
    """str: Do not log new entries."""
    DISCARD_OLDEST = "eventlog.DISCARD_OLDEST"
    """str: Delete old entries are deleted as new events are logged."""
    ENABLE = "eventlog.ENABLE"
    """str: Enable the event log."""

    def __init__(self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "eventlog") -> None:
        super().__init__(device, cmd_syntax)



"""DMM7500 package init file."""
from tm_devices.drivers.pi.digital_multimeters.dmm7500.dmm7500 import DMM7500
from tm_devices.drivers.pi.digital_multimeters.dmm7500.dmm7510 import DMM7510
from tm_devices.drivers.pi.digital_multimeters.dmm7500.dmm7512 import DMM7512

__all__ = [
    "DMM7500",
    "DMM7510",
    "DMM7512",
]



"""The errlog commands module.

These commands are used in the following models:
DPO2K, DPO2KB, DPO4K, DPO4KB, MDO3, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO2K, MSO2KB, MSO4K, MSO4KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - ERRlog {CLEar}
    - ERRlog:FIRst?
    - ERRlog:NEXt?
    - ERRlog:NUMENTries?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class ErrlogNumentries(SCPICmdRead):
    """The ``ERRlog:NUMENTries`` command.

    **Description:**
        - Returns the specified number of entries in the error log.

    **Usage:**
        - Using the ``.query()`` method will send the ``ERRlog:NUMENTries?`` query.
        - Using the ``.verify(value)`` method will send the ``ERRlog:NUMENTries?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ERRlog:NUMENTries?
    """


class ErrlogNext(SCPICmdRead):
    """The ``ERRlog:NEXt`` command.

    **Description:**
        - Returns the next entry in the error log (auto-incrementing).

    **Usage:**
        - Using the ``.query()`` method will send the ``ERRlog:NEXt?`` query.
        - Using the ``.verify(value)`` method will send the ``ERRlog:NEXt?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ERRlog:NEXt?
    """


class ErrlogFirst(SCPICmdRead):
    """The ``ERRlog:FIRst`` command.

    **Description:**
        - Returns the first entry in the Error Log.

    **Usage:**
        - Using the ``.query()`` method will send the ``ERRlog:FIRst?`` query.
        - Using the ``.verify(value)`` method will send the ``ERRlog:FIRst?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ERRlog:FIRst?
    """


class Errlog(SCPICmdWrite, SCPICmdRead):
    """The ``ERRlog`` command.

    **Description:**
        - Clears the oscilloscope error log.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``ERRlog value`` command.

    **SCPI Syntax:**

    ::

        - ERRlog {CLEar}

    **Info:**
        - ``CLear``

    Properties:
        - ``.first``: The ``ERRlog:FIRst`` command.
        - ``.next``: The ``ERRlog:NEXt`` command.
        - ``.numentries``: The ``ERRlog:NUMENTries`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "ERRlog") -> None:
        super().__init__(device, cmd_syntax)
        self._first = ErrlogFirst(device, f"{self._cmd_syntax}:FIRst")
        self._next = ErrlogNext(device, f"{self._cmd_syntax}:NEXt")
        self._numentries = ErrlogNumentries(device, f"{self._cmd_syntax}:NUMENTries")

    @property
    def first(self) -> ErrlogFirst:
        """Return the ``ERRlog:FIRst`` command.

        **Description:**
            - Returns the first entry in the Error Log.

        **Usage:**
            - Using the ``.query()`` method will send the ``ERRlog:FIRst?`` query.
            - Using the ``.verify(value)`` method will send the ``ERRlog:FIRst?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ERRlog:FIRst?
        """
        return self._first

    @property
    def next(self) -> ErrlogNext:
        """Return the ``ERRlog:NEXt`` command.

        **Description:**
            - Returns the next entry in the error log (auto-incrementing).

        **Usage:**
            - Using the ``.query()`` method will send the ``ERRlog:NEXt?`` query.
            - Using the ``.verify(value)`` method will send the ``ERRlog:NEXt?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ERRlog:NEXt?
        """
        return self._next

    @property
    def numentries(self) -> ErrlogNumentries:
        """Return the ``ERRlog:NUMENTries`` command.

        **Description:**
            - Returns the specified number of entries in the error log.

        **Usage:**
            - Using the ``.query()`` method will send the ``ERRlog:NUMENTries?`` query.
            - Using the ``.verify(value)`` method will send the ``ERRlog:NUMENTries?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ERRlog:NUMENTries?
        """
        return self._numentries
